@@ -88,9 +88,9 @@ static void help(void)
 
 }
 
+static struct cfgstruct *copt;
 int main(int argc, char **argv)
 {
-	struct cfgstruct *copt;
 	const struct cfgstruct *cpt;
 #ifndef	C_WINDOWS
         struct passwd *user = NULL;
@@ -124,7 +124,7 @@ int main(int argc, char **argv)
     }
 #endif
 
-    opt = opt_parse(argc, argv, short_options, long_options, NULL);
+    opt = opt_parse(argc, argv, short_options, long_options, NULL, NULL);
     if(!opt) {
 	mprintf("!Can't parse the command line\n");
 	return 1;
