@@ -34,14 +34,6 @@ struct thrarg {
     const struct cl_limits *limits;
 };
 
-struct thrsession {
-    pthread_mutex_t mutex;
-    short int active;
-    pthread_t id;
-    time_t start;
-    int desc;
-} *ths;
-
 /* thread watcher arguments */
 struct thrwarg {
     int socketd;
@@ -54,7 +46,6 @@ struct thrwarg {
 int acceptloop_th(int *socketds, int nsockets, struct cl_engine *engine, unsigned int dboptions, const struct cfgstruct *copt);
 void sighandler(int sig);
 void sighandler_th(int sig);
-void daemonize(void);
 void sigsegv(int sig);
 
 #endif
