@@ -25,17 +25,26 @@
 #ifdef	_MSC_VER
 #include <winsock.h>	/* only needed in CL_EXPERIMENTAL */
 #endif
-
 #if HAVE_CONFIG_H
 #include "clamav-config.h"
 #endif
 
+/* for strptime, it is POSIX, but defining _XOPEN_SOURCE to 600
+ * fails on Solaris because it would require a c99 compiler,
+ * 500 fails completely on Solaris, and FreeBSD, and w/o _XOPEN_SOURCE
+ * strptime is not defined on Linux */
+#define _GNU_SOURCE
+#define __EXTENSIONS
+
 #include <stdio.h>
 #include <stdlib.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #include <string.h>
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
 #include <ctype.h>
 #ifndef C_WINDOWS
 #include <netinet/in.h>
@@ -89,7 +98,7 @@
 	if(chdir(x) == -1)			\
 	    logg("!Can't chdir to %s\n", x);
 
-#ifndef SUPPORT_IPv6
+#ifndef HAVE_GETADDRINFO
 static const char *ghbn_err(int err) /* hstrerror() */
 {
     switch(err) {
@@ -116,21 +125,18 @@ static int getclientsock(const char *localip, int prot)
 	int socketfd = -1;
 
 #ifdef SUPPORT_IPv6
-    if(prot == PF_INET6)
-	socketfd = socket(PF_INET6, SOCK_STREAM, 0);
+    if(prot == AF_INET6)
+	socketfd = socket(AF_INET6, SOCK_STREAM, 0);
     else
-	socketfd = socket(PF_INET, SOCK_STREAM, 0);
-#else
-    socketfd = socket(PF_INET, SOCK_STREAM, 0);
 #endif
-
+	socketfd = socket(AF_INET, SOCK_STREAM, 0);
     if(socketfd < 0) {
 	logg("!Can't create new socket\n");
 	return -1;
     }
 
     if(localip) {
-#ifdef SUPPORT_IPv6
+#ifdef HAVE_GETADDRINFO
 	    struct addrinfo *res;
 	    int ret;
 
@@ -147,9 +153,11 @@ static int getclientsock(const char *localip, int prot)
 	    } else {
 		    void *addr;
 
+#ifdef SUPPORT_IPv6
 		if(res->ai_family == AF_INET6)
 		    addr = &((struct sockaddr_in6 *) res->ai_addr)->sin6_addr;
 		else
+#endif
 		    addr = &((struct sockaddr_in *) res->ai_addr)->sin_addr;
 
 		if(inet_ntop(res->ai_family, addr, ipaddr, sizeof(ipaddr)))
@@ -191,7 +199,7 @@ static int wwwconnect(const char *server, const char *proxy, int pport, char *ip
 {
 	int socketfd, port, ret;
 	unsigned int ips = 0, ignored = 0;
-#ifdef SUPPORT_IPv6
+#ifdef HAVE_GETADDRINFO
 	struct addrinfo hints, *res = NULL, *rp, *loadbal_rp = NULL;
 	char port_s[6], loadbal_ipaddr[46];
 	uint32_t loadbal = 1, minsucc = 0xffffffff, minfail = 0xffffffff;
@@ -229,9 +237,13 @@ static int wwwconnect(const char *server, const char *proxy, int pport, char *ip
 	port = 80;
     }
 
-#ifdef SUPPORT_IPv6
+#ifdef HAVE_GETADDRINFO
     memset(&hints, 0, sizeof(hints));
+#ifdef SUPPORT_IPv6
     hints.ai_family = AF_UNSPEC;
+#else
+    hints.ai_family = AF_INET;
+#endif
     hints.ai_socktype = SOCK_STREAM;
     snprintf(port_s, sizeof(port_s), "%d", port);
     port_s[sizeof(port_s) - 1] = 0;
@@ -245,9 +257,11 @@ static int wwwconnect(const char *server, const char *proxy, int pport, char *ip
 	    void *addr;
 
 	ips++;
+#ifdef SUPPORT_IPv6
 	if(rp->ai_family == AF_INET6)
 	    addr = &((struct sockaddr_in6 *) rp->ai_addr)->sin6_addr;
 	else
+#endif
 	    addr = &((struct sockaddr_in *) rp->ai_addr)->sin_addr;
 
 	if(!inet_ntop(rp->ai_family, addr, ipaddr, sizeof(ipaddr))) {
@@ -256,7 +270,7 @@ static int wwwconnect(const char *server, const char *proxy, int pport, char *ip
 	    return -1;
 	}
 
-	if((ret = mirman_check(addr, rp->ai_family, mdat, &md))) {
+	if(mdat && (ret = mirman_check(addr, rp->ai_family, mdat, &md))) {
 	    if(ret == 1)
 		logg("Ignoring mirror %s (due to previous errors)\n", ipaddr);
 	    else
@@ -267,7 +281,7 @@ static int wwwconnect(const char *server, const char *proxy, int pport, char *ip
 		continue;
 	}
 
-	if(loadbal) {
+	if(mdat && loadbal) {
 	    if(!ret) {
 		if(!md) {
 		    loadbal_rp = rp;
@@ -323,11 +337,13 @@ static int wwwconnect(const char *server, const char *proxy, int pport, char *ip
 	    }
 	    continue;
 	} else {
-	    if(rp->ai_family == AF_INET)
-		mdat->currip[0] = *((uint32_t *) addr);
-	    else
-		memcpy(mdat->currip, addr, 4 * sizeof(uint32_t));
-	    mdat->af = rp->ai_family;
+	    if(mdat) {
+		if(rp->ai_family == AF_INET)
+		    mdat->currip[0] = *((uint32_t *) addr);
+		else
+		    memcpy(mdat->currip, addr, 4 * sizeof(uint32_t));
+		mdat->af = rp->ai_family;
+	    }
 	    freeaddrinfo(res);
 	    return socketfd;
 	}
@@ -347,7 +363,7 @@ static int wwwconnect(const char *server, const char *proxy, int pport, char *ip
 	sprintf(ipaddr, "%u.%u.%u.%u", ia[0], ia[1], ia[2], ia[3]);
 
 	ips++;
-	if((ret = mirman_check(&((struct in_addr *) ia)->s_addr, AF_INET, mdat, NULL))) {
+	if(mdat && (ret = mirman_check(&((struct in_addr *) ia)->s_addr, AF_INET, mdat, NULL))) {
 	    if(ret == 1)
 		logg("Ignoring mirror %s (due to previous errors)\n", ipaddr);
 	    else
@@ -380,19 +396,315 @@ static int wwwconnect(const char *server, const char *proxy, int pport, char *ip
 	    closesocket(socketfd);
 	    continue;
 	} else {
-	    mdat->currip[0] = ((struct in_addr *) ia)->s_addr;
-	    mdat->af = AF_INET;
+	    if(mdat) {
+		mdat->currip[0] = ((struct in_addr *) ia)->s_addr;
+		mdat->af = AF_INET;
+	    }
 	    return socketfd;
 	}
     }
 #endif
 
-    if(can_whitelist && ips && (ips == ignored))
+    if(mdat && can_whitelist && ips && (ips == ignored))
 	mirman_whitelist(mdat);
 
     return -2;
 }
 
+static const char *readbline(int fd, char *buf, int bufsize, int filesize, int *bread)
+{
+	char *pt;
+	int ret, end;
+
+    if(!*bread) {
+	if(bufsize < filesize)
+	    lseek(fd, -bufsize, SEEK_END);
+	*bread = read(fd, buf, bufsize - 1);
+	if(!*bread || *bread == -1)
+	    return NULL;
+	buf[*bread] = 0;
+    }
+
+    pt = strrchr(buf, '\n');
+    if(!pt)
+	return NULL;
+    *pt = 0;
+    pt = strrchr(buf, '\n');
+    if(pt) {
+	return ++pt;
+    } else if(*bread == filesize) {
+	return buf;
+    } else {
+	*bread -= strlen(buf) + 1;
+	end = filesize - *bread;
+	if(end < bufsize) {
+	    if((ret = lseek(fd, 0, SEEK_SET)) != -1)
+		ret = read(fd, buf, end);
+	} else {
+	    if((ret = lseek(fd, end - bufsize, SEEK_SET)) != -1)
+		ret = read(fd, buf, bufsize - 1);
+	}
+	if(!ret || ret == -1)
+	    return NULL;
+	buf[ret] = 0;
+	*bread += ret;
+	pt = strrchr(buf, '\n');
+	if(!pt)
+	    return buf;
+	*pt = 0;
+	pt = strrchr(buf, '\n');
+	if(pt)
+	    return ++pt;
+	else if(strlen(buf))
+	    return buf;
+	else 
+	    return NULL;
+    }
+}
+
+/*
+ * TODO:
+ * - strptime() is most likely not portable enough
+ * - proxy support
+ */
+int submitstats(const char *clamdcfg, const struct cfgstruct *copt)
+{
+	int fd, sd, bread, lread = 0, cnt, ret;
+	char post[SUBMIT_MIN_ENTRIES * 256 + 512];
+	char query[SUBMIT_MIN_ENTRIES * 256];
+	char buff[512], statsdat[512], newstatsdat[512], uastr[128];
+	char logfile[256], fbuff[FILEBUFF];
+	char *pt, *pt2;
+	const char *line, *country = NULL;
+	struct cfgstruct *clamdopt;
+	const struct cfgstruct *cpt;
+	struct stat sb;
+	struct tm tms;
+	time_t epoch;
+	unsigned int qcnt, entries, submitted = 0, permfail = 0;
+
+
+    if((cpt = cfgopt(copt, "DetectionStatsCountry"))->enabled) {
+	if(strlen(cpt->strarg) != 2 || !isalpha(cpt->strarg[0]) || !isalpha(cpt->strarg[1])) {
+	    logg("!SubmitDetectionStats: DetectionStatsCountry requires a two-letter country code\n");
+	    return 56;
+	}
+	country = cpt->strarg;
+    }
+
+    if(!(clamdopt = getcfg(clamdcfg, 1))) {
+	logg("!SubmitDetectionStats: Can't open or parse configuration file %s\n", clamdcfg);
+	return 56;
+    }
+
+    if(!(cpt = cfgopt(clamdopt, "LogFile"))->enabled) {
+	logg("!SubmitDetectionStats: LogFile needs to be enabled in %s\n", clamdcfg);
+	freecfg(clamdopt);
+	return 56;
+    }
+    strncpy(logfile, cpt->strarg, sizeof(logfile));
+    logfile[sizeof(logfile) - 1] = 0;
+
+    if(!cfgopt(clamdopt, "LogTime")->enabled) {
+	logg("!SubmitDetectionStats: LogTime needs to be enabled in %s\n", clamdcfg);
+	freecfg(clamdopt);
+	return 56;
+    }
+    freecfg(clamdopt);
+
+    if((fd = open("stats.dat", O_RDONLY)) != -1) {
+	if((bread = read(fd, statsdat, sizeof(statsdat) - 1)) == -1) {
+	    logg("^SubmitDetectionStats: Can't read stats.dat\n");
+	    bread = 0;
+	}
+	statsdat[bread] = 0;
+	close(fd);
+    } else {
+	*statsdat = 0;
+    }
+
+    if((fd = open(logfile, O_RDONLY)) == -1) {
+	logg("!SubmitDetectionStats: Can't open %s for reading\n", logfile);
+	return 56;
+    }
+
+    if(fstat(fd, &sb) == -1) {
+	logg("!SubmitDetectionStats: fstat() failed\n");
+	close(fd);
+	return 56;
+    }
+
+    while((line = readbline(fd, fbuff, FILEBUFF, sb.st_size, &lread)))
+	if(strlen(line) >= 32 && !strcmp(&line[strlen(line) - 6], " FOUND"))
+	    break;
+
+    if(!line) {
+	logg("SubmitDetectionStats: No detection records found\n");
+	close(fd);
+	return 1;
+    }
+
+    if(*statsdat && !strcmp(line, statsdat)) {
+	logg("SubmitDetectionStats: No new detection records found\n");
+	close(fd);
+	return 1;
+    } else {
+	strncpy(newstatsdat, line, sizeof(newstatsdat));
+    }
+
+    if((cpt = cfgopt(copt, "HTTPUserAgent"))->enabled)
+	strncpy(uastr, cpt->strarg, sizeof(uastr));
+    else
+	snprintf(uastr, sizeof(uastr), PACKAGE"/%s (OS: "TARGET_OS_TYPE", ARCH: "TARGET_ARCH_TYPE", CPU: "TARGET_CPU_TYPE")%s%s", get_version(), country ? ":" : "", country ? country : "");
+    uastr[sizeof(uastr) - 1] = 0;
+
+    ret = 0;
+    memset(query, 0, sizeof(query));
+    qcnt = 0;
+    entries = 0;
+    do {
+	if(strlen(line) < 32 || strcmp(&line[strlen(line) - 6], " FOUND"))
+	    continue;
+
+	if(*statsdat && !strcmp(line, statsdat))
+	    break;
+
+	strncpy(buff, line, sizeof(buff));
+	buff[sizeof(buff) - 1] = 0;
+
+	if(!(pt = strstr(buff, " -> "))) {
+	    logg("*SubmitDetectionStats: Skipping detection entry logged without time\b");
+	    continue;
+	}
+	*pt = 0;
+	pt += 4;
+
+	if(!strptime(buff, "%a %b  %d %H:%M:%S %Y", &tms) || (epoch = mktime(&tms)) == -1) {
+	    logg("!SubmitDetectionStats: Failed to convert date string\n");
+	    ret = 1;
+	    break;
+	}
+
+	pt2 = &pt[strlen(pt) - 6];
+	*pt2 = 0;
+
+	if(!(pt2 = strrchr(pt, ':'))) {
+	    logg("!SubmitDetectionStats: Incorrect format of the log file (1)\n");
+	    ret = 1;
+	    break;
+	}
+	*pt2 = 0;
+	pt2 += 2;
+
+#ifdef C_WINDOWS
+	if((pt = strrchr(pt, '\\')))
+#else
+	if((pt = strrchr(pt, '/')))
+#endif
+	    *pt++ = 0;
+	if(!pt)
+	    pt = (char*) "NOFNAME";
+
+	qcnt += snprintf(&query[qcnt], sizeof(query) - qcnt, "ts[]=%u&fname[]=%s&virus[]=%s&", (unsigned int) epoch, pt, pt2);
+	entries++;
+
+	if(entries == SUBMIT_MIN_ENTRIES) {
+	    sd = wwwconnect("stats.clamav.net", NULL, 0, NULL, cfgopt(copt, "LocalIPAddress")->strarg, cfgopt(copt, "ConnectTimeout")->numarg, NULL, 0, 0);
+	    if(sd == -1) {
+		logg("!SubmitDetectionStats: Can't connect to server\n");
+		ret = 52;
+		break;
+	    }
+
+	    query[sizeof(query) - 1] = 0;
+	    snprintf(post, sizeof(post),
+		"POST /submit.php HTTP/1.0\r\n"
+		"Host: stats.clamav.net\r\n"
+		"Content-Type: application/x-www-form-urlencoded\r\n"
+		"User-Agent: %s\r\n"
+		"Content-Length: %u\r\n\n"
+		"%s",
+	    uastr, (unsigned int) strlen(query), query);
+
+	    if(send(sd, post, strlen(post), 0) < 0) {
+		logg("!SubmitDetectionStats: Can't write to socket\n");
+		ret = 52;
+		closesocket(sd);
+		break;
+	    }
+
+	    pt = post;
+	    cnt = sizeof(post) - 1;
+#ifdef SO_ERROR
+	    while((bread = wait_recv(sd, pt, cnt, 0, cfgopt(copt, "ReceiveTimeout")->numarg)) > 0) {
+#else
+	    while((bread = recv(sd, pt, cnt, 0)) > 0) {
+#endif
+		pt += bread;
+		cnt -= bread;
+		if(cnt <= 0)
+		    break;
+	    }
+	    *pt = 0;
+	    closesocket(sd);
+
+	    if(bread < 0) {
+		logg("!SubmitDetectionStats: Can't read from socket\n");
+		ret = 52;
+		break;
+	    }
+
+	    if(strstr(post, "SUBMIT_OK")) {
+		submitted += entries;
+		if(submitted + SUBMIT_MIN_ENTRIES > SUBMIT_MAX_ENTRIES)
+		    break;
+		qcnt = 0;
+		entries = 0;
+		memset(query, 0, sizeof(query));
+		continue;
+	    }
+
+	    ret = 52;
+	    if(strstr(post, "SUBMIT_PERMANENT_FAILURE")) {
+		if(!submitted) {
+		    logg("!SubmitDetectionStats: Permanent failure\n");
+		    permfail = 1;
+		}
+	    } else if(strstr(post, "SUBMIT_TEMPORARY_FAILURE")) {
+		if(!submitted)
+		    logg("!SubmitDetectionStats: Temporary failure\n");
+	    } else {
+		if(!submitted)
+		    logg("!SubmitDetectionStats: Incorrect answer from server\n");
+	    }
+
+	    break;
+	}
+
+    } while((line = readbline(fd, fbuff, FILEBUFF, sb.st_size, &lread)));
+
+    close(fd);
+
+    if(submitted || permfail) {
+	if((fd = open("stats.dat", O_WRONLY | O_CREAT | O_TRUNC, 0600)) == -1) {
+	    logg("^SubmitDetectionStats: Can't open stats.dat for writing\n");
+	} else {
+	    if((bread = write(fd, newstatsdat, sizeof(newstatsdat))) != sizeof(newstatsdat))
+		logg("^SubmitDetectionStats: Can't write to stats.dat\n");
+	    close(fd);
+	}
+    }
+
+    if(ret == 0) {
+	if(!submitted)
+	    logg("SubmitDetectionStats: Not enough recent data for submission\n");
+	else
+	    logg("SubmitDetectionStats: Submitted %u records\n", submitted);
+    }
+
+    return ret;
+}
+
 static int Rfc2822DateTime(char *buf, time_t mtime)
 {
 	struct tm *gmt;
@@ -1374,7 +1686,7 @@ int downloadmanager(const struct cfgstruct *copt, const struct optstruct *opt, c
 
     time(&currtime);
     logg("ClamAV update process started at %s", ctime(&currtime));
-#ifdef SUPPORT_IPv6
+#ifdef HAVE_GETADDRINFO
     logg("*Using IPv6 aware code\n");
 #endif
 
@@ -1421,19 +1733,23 @@ int downloadmanager(const struct cfgstruct *copt, const struct optstruct *opt, c
 		}
 
 		if((newver = cli_strtok(dnsreply, 0, ":"))) {
+			char vstr[32];
 
 		    logg("*Software version from DNS: %s\n", newver);
+		    strncpy(vstr, get_version(), 32);
+		    vstr[31] = 0;
+		    if((pt = strstr(vstr, "-exp")) || (pt = strstr(vstr,"-broken")))
+			*pt = 0;
 
-		    if(vwarning && !strstr(get_version(), "devel") && !strstr(get_version(), "rc")) {
-			if(strcmp(get_version(), newver)) {
+		    if(vwarning && !strstr(vstr, "devel") && !strstr(vstr, "rc")) {
+			if(strcmp(vstr, newver)) {
 			    logg("^Your ClamAV installation is OUTDATED!\n");
-			    logg("^Local version: %s Recommended version: %s\n", get_version(), newver);
+			    logg("^Local version: %s Recommended version: %s\n", vstr, newver);
 			    logg("DON'T PANIC! Read http://www.clamav.net/support/faq\n");
 			    outdated = 1;
 			}
 		    }
 		}
-
 	    }
 	}
 
