@@ -613,7 +613,7 @@ static int cli_html_normalise(int fd, m_area_t *m_area, const char *dirname, tag
 	unsigned long length;
 	struct screnc_state screnc_state;
 	file_buff_t *file_buff_o2, *file_buff_text;
-	file_buff_t *file_tmp_o1 = NULL;
+	file_buff_t *file_tmp_o1;
 	int in_ahref=0;/* index of <a> tag, whose contents we are parsing. Indexing starts from 1, 0 means outside of <a>*/
 	unsigned char* href_contents_begin=NULL;/*beginning of the next portion of <a> contents*/
 	unsigned char* ptrend=NULL;/*end of <a> contents*/
@@ -1485,6 +1485,7 @@ static int cli_html_normalise(int fd, m_area_t *m_area, const char *dirname, tag
 					snprintf(filename, 1024, "%s/rfc2397", dirname);
 					tmp_file = cli_gentemp(filename);
 					if(!tmp_file) {
+						free(file_tmp_o1);
 						goto abort;
 					}
 					cli_dbgmsg("RFC2397 data file: %s\n", tmp_file);
@@ -1492,6 +1493,7 @@ static int cli_html_normalise(int fd, m_area_t *m_area, const char *dirname, tag
 					free(tmp_file);
 					if (file_tmp_o1->fd < 0) {
 						cli_dbgmsg("open failed: %s\n", filename);
+						free(file_tmp_o1);
 						goto abort;
 					}
 					file_tmp_o1->length = 0;
@@ -1563,7 +1565,6 @@ static int cli_html_normalise(int fd, m_area_t *m_area, const char *dirname, tag
 					html_output_flush(file_tmp_o1);
 					close(file_tmp_o1->fd);
 					free(file_tmp_o1);
-					file_tmp_o1 = NULL;
 				}
 				state = HTML_SKIP_WS;
 				escape = FALSE;
@@ -1687,11 +1688,6 @@ abort:
 			close(file_buff_text->fd);
 		free(file_buff_text);
 	}
-	if(file_tmp_o1) {
-		html_output_flush(file_tmp_o1);
-		close(file_tmp_o1->fd);
-		free(file_tmp_o1);
-	}
 	return retval;
 }
 
