@@ -85,7 +85,7 @@ int cli_check_mydoom_log(int desc, const char **virname)
     return retval;
 }
 
-static int jpeg_check_photoshop_8bim(int fd, cli_ctx *ctx)
+static int jpeg_check_photoshop_8bim(int fd)
 {
 	unsigned char bim[5];
 	uint16_t id, ntmp;
@@ -140,7 +140,7 @@ static int jpeg_check_photoshop_8bim(int fd, cli_ctx *ctx)
 	/* Jump past header */
 	lseek(fd, 28, SEEK_CUR);
 
-	retval = cli_check_jpeg_exploit(fd, ctx);
+	retval = cli_check_jpeg_exploit(fd);
 	if (retval == 1) {
 		cli_dbgmsg("Exploit found in thumbnail\n");
 	}
@@ -149,7 +149,7 @@ static int jpeg_check_photoshop_8bim(int fd, cli_ctx *ctx)
 	return retval;
 }
 
-static int jpeg_check_photoshop(int fd, cli_ctx *ctx)
+static int jpeg_check_photoshop(int fd)
 {
 	int retval;
 	unsigned char buffer[14];
@@ -166,7 +166,7 @@ static int jpeg_check_photoshop(int fd, cli_ctx *ctx)
 	cli_dbgmsg("Found Photoshop segment\n");
 	do {
 		old = lseek(fd, 0, SEEK_CUR);
-		retval = jpeg_check_photoshop_8bim(fd, ctx);
+		retval = jpeg_check_photoshop_8bim(fd);
 		new = lseek(fd, 0, SEEK_CUR);
 		if(new <= old)
 			break;
@@ -178,7 +178,7 @@ static int jpeg_check_photoshop(int fd, cli_ctx *ctx)
 	return retval;
 }
 
-int cli_check_jpeg_exploit(int fd, cli_ctx *ctx)
+int cli_check_jpeg_exploit(int fd)
 {
 	unsigned char buffer[4];
 	off_t offset;
@@ -186,8 +186,6 @@ int cli_check_jpeg_exploit(int fd, cli_ctx *ctx)
 
 
 	cli_dbgmsg("in cli_check_jpeg_exploit()\n");
-	if(ctx->recursion > ctx->limits->maxreclevel)
-	    return CL_EMAXREC;
 
 	if (cli_readn(fd, buffer, 2) != 2) {
 		return 0;
@@ -231,11 +229,9 @@ int cli_check_jpeg_exploit(int fd, cli_ctx *ctx)
 
 		if (buffer[1] == 0xed) {
 			/* Possible Photoshop file */
-			ctx->recursion++;
-			retval=jpeg_check_photoshop(fd, ctx);
-			ctx->recursion--;
-			if (retval != 0)
+			if ((retval=jpeg_check_photoshop(fd)) != 0) {
 				return retval;
+			}
 		}
 
 		if (lseek(fd, offset, SEEK_SET) != offset) {
