@@ -1,10 +1,11 @@
 /*
- *  Copyright (C) 2002 Nigel Horne <njh@bandsman.co.uk>
+ *  Copyright (C) 2007-2008 Sourcefire, Inc.
+ *
+ *  Authors: Nigel Horne
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -119,6 +120,9 @@ tableInsert(table_t *table, const char *key, int value)
 /*
  * Returns the value - -1 for not found. This means the value of a valid key
  *	can't be -1 :-(
+ *
+ * Linear search. Since tables are rarely more than 3 or 4 in size, and never
+ *	reach double figures, there's no need for optimisation
  */
 int
 tableFind(const table_t *table, const char *key)
