@@ -2,7 +2,7 @@
 # Run under electric-fence
 LIBDIRS=`../libtool --config | grep sys_lib_search_path_spec | sed -e 's/.*"\(.*\)"/\1/'`
 if test -z "$LIBEFENCE"; then
-	for i in $LIBDIRS /usr/local/lib; do
+	for i in $LIBDIRS; do
 		if test -f "$i/libefence.so"; then
 			LIBEFENCE="$i/libefence.so"
 			break;
